@@ -8,6 +8,7 @@ from helix_personmatching.fhir_manager.fhir_to_dict_manager.fhir_to_dict_manager
     FhirToAttributeDict,
 )
 from helix_personmatching.logics.scoring_input import ScoringInput
+from helix_personmatching.utils.json_serializer import EnhancedJSONEncoder
 
 
 @pytest.mark.parametrize("patient", ["patient1", "patient2"])
@@ -26,7 +27,7 @@ def test_fhir_to_dict_manager(patient: str) -> None:
         resource=patient
     )
 
-    scoring_json = json.dumps(scoring_input, default=str)
+    scoring_json = json.dumps(scoring_input, cls=EnhancedJSONEncoder)
     print(scoring_json)
 
     with open(test_file_dir.joinpath("expected.json")) as file:
