@@ -10,7 +10,11 @@ from helix_personmatching.models.scoring_option import ScoringOption
 
 class RulesGenerator:
     @staticmethod
-    def generate_rules(*, options: Optional[List[ScoringOption]] = None) -> List[Rule]:
+    def generate_rules(
+        *,
+        only_use_passed_in_rules: Optional[bool] = None,
+        options: Optional[List[ScoringOption]] = None,
+    ) -> List[Rule]:
         """
         generate default match rules
         :return: generated rules for matching
@@ -262,7 +266,7 @@ class RulesGenerator:
                 # https://sequoiaproject.org/wp-content/uploads/2015/11/The-Sequoia-Project-Framework-for-Patient-Identity-Management.pdf
                 name="Rule-017",
                 description="given name, last name, date of birth, gender, SSN (last 4)",
-                number=16,
+                number=17,
                 attributes=[
                     Attribute.NAME_GIVEN,
                     Attribute.NAME_FAMILY,
@@ -273,8 +277,31 @@ class RulesGenerator:
                 # 7         FN+LN+DoB+Sex+SSN(last 4)   61.9%           99.7%
                 weight=RuleWeight(exact_match=0.997, partial_match=0.997, missing=0.75),
             ),
+            # Rules with rule number 900 and above are for limited availability of each partial demographics data
+            #  initially enabled=False, these rules will be enabled depending on which data available,
+            #    with all other rules (< rule number 900) disabled, IF a specific data connection type is set
+            #    with a list of available data properties when the pipeline is called
+            AttributeRule(
+                name="Rule-900",  # for Patient/Person name only. for instance, for HAPI LabCorp connection
+                description="first name, last name",
+                number=900,
+                attributes=[
+                    Attribute.NAME_GIVEN,
+                    Attribute.NAME_FAMILY,
+                ],
+                weight=standard_weight,
+                enabled=False,
+            ),
         ]
 
+        # IF this is set to True,
+        if only_use_passed_in_rules is not None and only_use_passed_in_rules is True:
+            # disable all other normal rules first,
+            for rule in list(filter(lambda r: r.number < 900, rules)):
+                rule.enabled = False
+
+            # then later enable only rules configured/set from the options parameters
+
         if options and len(options) > 0:
             available_extra_rules = [
                 BoosterRule(
@@ -300,6 +327,8 @@ class RulesGenerator:
                 ]
                 if len(matching_rules) > 0:
                     matching_rule = matching_rules[0]
+                    # enable the found/matched rule in the configured options
+                    matching_rule.enabled = True
                     if option.weight is not None:
                         matching_rule.weight = option.weight
 
