@@ -7,9 +7,9 @@ from helix_personmatching.logics.match_score_without_threshold import (
 )
 from helix_personmatching.logics.rule_score import RuleScore
 from helix_personmatching.logics.scoring_input import ScoringInput
+from helix_personmatching.logics.nick_names.nick_name_loader import NickNameLoader
 from helix_personmatching.models.rule import Rule
 from helix_personmatching.models.rule_option import RuleOption
-from helix_personmatching.nick_name_loader import NickNameLoader
 
 
 class ScoreCalculator:
@@ -49,10 +49,9 @@ class ScoreCalculator:
                 average_boost=None,
                 average_score=0.0,
             )
+
         # Get the average match score as "final score" result
-        # AND we're not penalizing the total match score,
-        #  by excluding those rules that have 0 match scores when calculating the final match score,
-        #  meaning the required data attributes/fields in the rule are not available or absent.
+
         final_score: float = 0
 
         sum_of_scores: float = 0
@@ -119,6 +118,7 @@ class ScoreCalculator:
     ) -> List[RuleScore]:
         """
         Calculate matching scores for ALL rules between FHIR Person-Person, or Person-Patient, or Person/Patient-AppUser
+
         :param rules: generated rules by RulesGenerator
         :param source: Dictionary of Pii data for FHIR Person/Patient data, or AppUser data
         :param target: Dictionary of Pii data for FHIR Person/Patient data, or AppUser data
@@ -153,4 +153,8 @@ class ScoreCalculator:
         target: ScoringInput,
         rule_option: RuleOption
     ) -> Optional[RuleScore]:
-        return rule.score(source=source, target=target, rule_option=rule_option)
+        return (
+            rule.score(source=source, target=target, rule_option=rule_option)
+            if rule.enabled is True
+            else None
+        )
