@@ -21,10 +21,15 @@ class AttributeRule(Rule):
         description: str,
         number: int,
         attributes: List[AttributeEntry],
-        weight: RuleWeight
+        weight: RuleWeight,
+        enabled: Optional[bool] = True
     ) -> None:
         super().__init__(
-            name=name, description=description, number=number, weight=weight
+            name=name,
+            description=description,
+            number=number,
+            weight=weight,
+            enabled=enabled,
         )
         self.attributes: List[AttributeEntry] = attributes
 
@@ -34,8 +39,7 @@ class AttributeRule(Rule):
         """
         Calculate a matching score for one rule between FHIR Person-Person, or Person-Patient, or Person/Patient-AppUser
 
-
-        :param rule_option:
+        :param rule_option: Options for rules for calculating string match
         :param source: Dictionary of Pii data for FHIR Person/Patient data, or AppUser data
         :param target: Dictionary of Pii data for FHIR Person/Patient data, or AppUser data
         :return: Dictionary of 1 rule score result
@@ -58,8 +62,7 @@ class AttributeRule(Rule):
             if val_source and val_target:
                 rule_attribute_score.present = True
 
-                # calculate exact string match on "trimmed lower" string values
-                # returns a number between 0 and 1
+                # calculate string match
                 score_for_attribute, string_match_type = self.calculate_string_match(
                     attribute=attribute,
                     val_source=val_source,
@@ -80,7 +83,7 @@ class AttributeRule(Rule):
 
         score_avg /= len(self.attributes)
 
-        my_score = (
+        final_rule_score = (
             self.weight.exact_match
             if score_avg == 1.0
             else (score_avg * self.weight.partial_match)
@@ -91,7 +94,7 @@ class AttributeRule(Rule):
             id_target=str(id_data_target),
             rule_name=self.name,
             rule_description=self.description,
-            rule_score=my_score,
+            rule_score=final_rule_score,
             rule_unweighted_score=score_avg,
             rule_weight=self.weight,
             attribute_scores=rule_attribute_scores,
@@ -110,7 +113,6 @@ class AttributeRule(Rule):
         """
         Returns a score from 0 to 1 where 1 is an exact match
 
-
         :param attribute:
         :param val_source:
         :param val_target:
@@ -126,6 +128,12 @@ class AttributeRule(Rule):
             else:
                 return 0.0, StringMatchType.NoMatch
 
+        # Calculates a normalized levenshtein similarity in the range [0, 1] using custom
+        #     costs for insertion, deletion and substitution.
+        #     This is calculated as `1 - normalized_distance`
+        # Algorithm - https://en.wikipedia.org/wiki/Levenshtein_distance
+        # Py pkg - https://github.com/maxbachmann/RapidFuzz/blob/main/src/rapidfuzz/distance/Levenshtein_py.py#L286
+
         score_for_attribute = distance.Levenshtein.normalized_similarity(
             val_source_cleansed,
             val_target_cleansed,
@@ -135,6 +143,9 @@ class AttributeRule(Rule):
         )
 
         # if exact match did not work then try matching on nicknames
+
+        # canonicals_of(): Returns a set of all the canonical names for a name.
+        # - https://github.com/carltonnorthern/nicknames/blob/master/python/src/nicknames/__init__.py#L61
         if score_for_attribute < 1.0 and attribute.nick_name_match:
             canonicals_source: Set[str] = nick_namer.canonicals_of(
                 val_source_cleansed
@@ -142,6 +153,8 @@ class AttributeRule(Rule):
             canonicals_target: Set[str] = nick_namer.canonicals_of(
                 val_target_cleansed
             ) | {val_target_cleansed}
+
+            # Return the intersection of two sets as a new set
             matching_set: Set[str] = canonicals_source.intersection(canonicals_target)
             if len(matching_set) > 0:
                 return 1.0, StringMatchType.Synonym
