@@ -9,10 +9,20 @@ from helix_personmatching.models.rules.RuleWeight import RuleWeight
 
 class BoosterRule(Rule):
     def __init__(
-        self, *, name: str, description: str, number: int, weight: RuleWeight
+        self,
+        *,
+        name: str,
+        description: str,
+        number: int,
+        weight: RuleWeight,
+        enabled: Optional[bool] = True
     ) -> None:
         super().__init__(
-            name=name, description=description, number=number, weight=weight
+            name=name,
+            description=description,
+            number=number,
+            weight=weight,
+            enabled=enabled,
         )
 
     def score(
